"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mri = require("mri");
const libyear_1 = require("./libyear");
const package_manager_1 = require("./package-manager");
const configuration_1 = require("./configuration");
const validateThreshold = (threshold) => isNaN(Number(threshold)) ? null : Number(threshold);
exports.cli = async () => {
    var _a, _b, _c, _d, _e, _f;
    // parse cli args
    const argv = process.argv.slice(2);
    const args = mri(argv);
    // validate cli options
    const packageManager = args["package-manager"];
    const { overrides, threshold } = await configuration_1.getConfiguration(args);
    const driftCollective = validateThreshold((_a = threshold === null || threshold === void 0 ? void 0 : threshold.drift) === null || _a === void 0 ? void 0 : _a.collective);
    const driftIndividual = validateThreshold((_b = threshold === null || threshold === void 0 ? void 0 : threshold.drift) === null || _b === void 0 ? void 0 : _b.individual);
    const pulseCollective = validateThreshold((_c = threshold === null || threshold === void 0 ? void 0 : threshold.pulse) === null || _c === void 0 ? void 0 : _c.collective);
    const pulseIndividual = validateThreshold((_d = threshold === null || threshold === void 0 ? void 0 : threshold.pulse) === null || _d === void 0 ? void 0 : _d.individual);
    const releasesCollective = validateThreshold((_e = threshold === null || threshold === void 0 ? void 0 : threshold.releases) === null || _e === void 0 ? void 0 : _e.collective);
    const releasesIndividual = validateThreshold((_f = threshold === null || threshold === void 0 ? void 0 : threshold.releases) === null || _f === void 0 ? void 0 : _f.individual);
    // run libyear
    libyear_1.libyear(package_manager_1.getParsedPackageManager(packageManager !== null && packageManager !== void 0 ? packageManager : (await package_manager_1.getInferredPackageManager())), {
        driftCollective,
        driftIndividual,
        pulseCollective,
        pulseIndividual,
        releasesCollective,
        releasesIndividual,
    }, overrides);
};
