"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const semver_1 = require("semver");
const dates_1 = require("./dates");
const dependencies_1 = require("./dependencies");
const print_1 = require("./print");
const release_time_1 = require("./release-time");
const versions_1 = require("./versions");
exports.libyear = async (packageManager, threshold, overrides) => {
    const awaitedDependencies = Object.entries(await dependencies_1.getDependencies(packageManager)).map(async ([dependency, currentVersion]) => {
        const releaseTime = await release_time_1.getReleaseTime(packageManager, dependency);
        const allVersionsObj = versions_1.getSanitisedReleases(releaseTime);
        const stableVersionsObj = versions_1.getStableReleases(allVersionsObj);
        const allVersions = Object.keys(allVersionsObj);
        const stableVersions = Object.keys(stableVersionsObj);
        const latestAllVersion = semver_1.sort(allVersions).slice(-1)[0];
        const latestStableVersion = semver_1.sort(stableVersions).slice(-1)[0];
        const drift = dates_1.calculateDrift(releaseTime[currentVersion], releaseTime[latestStableVersion]);
        const pulse = dates_1.calculatePulse(releaseTime[latestAllVersion]);
        const releases = allVersions
            .slice(allVersions.findIndex((version) => version === currentVersion) + 1, allVersions.findIndex((version) => version === latestStableVersion) + 1)
            .filter((version) => stableVersions.includes(version)).length;
        const status = Object.entries(releaseTime).length === 0
            ? "symlink"
            : stableVersions.includes(currentVersion)
                ? "stable"
                : "pre-release";
        const available = latestStableVersion != currentVersion
            ? latestStableVersion
            : latestAllVersion != currentVersion
                ? latestAllVersion
                : "N/A";
        return {
            dependency,
            drift,
            pulse,
            releases,
            status,
            available,
        };
    });
    Promise.all(awaitedDependencies)
        .then((dependencies) => {
        print_1.print(dependencies, threshold, overrides);
    })
        .catch((error) => {
        console.error(error.message);
    });
};
